@@ -120,7 +120,6 @@ class _ExperimentManager(object):
     def getCurveMatching(self, experiment: list, verbose=False):
         experiment_id = experiment if type(experiment[0]) == int else [exp.id for exp in experiment]
         params = {'exp_id': experiment_id}
-        print(params)
 
         address = 'ExperimentManager/API/getCurveMatching'
 
@@ -137,3 +136,23 @@ class _ExperimentManager(object):
                 print('Get Curve Matching executed successfully.')
 
         return json.loads(request.requests.text)
+
+    def getSimulation(self, experiment, verbose=False):
+        experiment_id = experiment if type(experiment) == int else experiment.id
+        params = {'exp_id': experiment_id}
+
+        address = 'ExperimentManager/API/getSimulation'
+
+        request = RequestAPI(ip=self.ip,
+                             port=self.port,
+                             address=address,
+                             token=self.token,
+                             mode=HTTP_TYPE.POST,
+                             secure=self.secure,
+                             params=params)
+
+        if request.requests.status_code == 200:
+            if verbose:
+                print('Get Simulation executed successfully.')
+
+        return json.loads(request.requests.text)
